ACPex.Schema.Session.NewResponse (ACPex v0.1.0)
View SourceResponse with the created session ID.
Sent by the agent in response to a NewSessionRequest, providing the unique identifier for the newly created session.
Required Fields
session_id- Unique session identifier (string)
Optional Fields
models- Available models for the session (map)modes- Available modes for the session (map)meta- Additional metadata (map)
Example
%ACPex.Schema.Session.NewResponse{
session_id: "session-123"
}JSON Representation
{
"sessionId": "session-123"
}
Summary
Functions
Creates a changeset for validation.
Types
Functions
@spec changeset(t(), map()) :: Ecto.Changeset.t()
Creates a changeset for validation.
Required Fields
session_id- Must be present